@@ -119,26 +119,23 @@ namespace shibsp {
     /** Matches based on metadata groups of requester. */
     extern SHIBSP_API xmltooling::QName AttributeRequesterInEntityGroupType;
 
-    /** Matches based on metadata groups of requester. */
-    extern SHIBSP_API xmltooling::QName InEntityGroupType;
-
     /** Matches based on entity attributes of issuer. */
     extern SHIBSP_API xmltooling::QName AttributeIssuerEntityAttributeExactMatchType;
 
     /** Matches based on entity attributes of requester. */
     extern SHIBSP_API xmltooling::QName AttributeRequesterEntityAttributeExactMatchType;
 
-    /** Matches based on entity attributes of requester. */
-    extern SHIBSP_API xmltooling::QName EntityAttributeExactMatchType;
-
     /** Matches based on entity attributes of issuer and a regex. */
     extern SHIBSP_API xmltooling::QName AttributeIssuerEntityAttributeRegexMatchType;
 
     /** Matches based on entity attributes of requester and a regex. */
     extern SHIBSP_API xmltooling::QName AttributeRequesterEntityAttributeRegexMatchType;
 
-    /** Matches based on entity attributes of requester and a regex. */
-    extern SHIBSP_API xmltooling::QName EntityAttributeRegexMatchType;
+    /** Matches based on NameIDFormats of issuer. */
+    extern SHIBSP_API xmltooling::QName AttributeIssuerNameIDFormatType;
+
+    /** Matches based on NameIDFormats of requester. */
+    extern SHIBSP_API xmltooling::QName AttributeRequesterNameIDFormatType;
 
     /** Matches based on issuer and pluggable criteria. */
     extern SHIBSP_API xmltooling::QName AttributeIssuerEntityMatcherType;
